fn write_single_file(path: &Path, instances: &[SolMacroGen]) -> Result<()>Expand description
Writes individually validated and formatted expansions without reparsing the combined output.
fn write_single_file(path: &Path, instances: &[SolMacroGen]) -> Result<()>Writes individually validated and formatted expansions without reparsing the combined output.